Skyr

† This functionality is planned. Skyr is a very young project, so be patient!

Skyr is a task runner, similar to Make. Just like Make, it can have tasks that depend on each other and are executed only if a file changes.†

However, unlike Make, Skyr doesn't actually have to be installed on your machine to run. That's because Skyr uses Shell scripts to define build commands and looks for special comments for special features. This means you can very easily integrate Skyr into your existing project.

## Install

Skyr is on PyPI, so you can install it like any other Python package. We prefer `pipx`:

    $ pipx install --force skyr
      installed package skyr 0.1.0, installed using Python 3.11.1
      These apps are now globally available
        - skyr
    done! ✨ 🌟 ✨

## Use

Run any script under `./script/` by providing its name:

this will run `script/test`

    $ skyr test

By default, Skyr runs the `build` script:

this will run `script/build`

    $ skyr

You can pass arguments to your scripts:

this will run `script/lint file.py`

    $ skyr lint file.py

## Work in progress

Skyr is still in development. If you want to contribute, fork it and submit a pull request. Your help is always appreciated.